summaryrefslogtreecommitdiffstats
path: root/cpukit/rtems/src/ratemoncreate.c
diff options
context:
space:
mode:
Diffstat (limited to 'cpukit/rtems/src/ratemoncreate.c')
-rw-r--r--cpukit/rtems/src/ratemoncreate.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/cpukit/rtems/src/ratemoncreate.c b/cpukit/rtems/src/ratemoncreate.c
index 5585a8ea36..01dffcca58 100644
--- a/cpukit/rtems/src/ratemoncreate.c
+++ b/cpukit/rtems/src/ratemoncreate.c
@@ -1,8 +1,7 @@
/*
* Rate Monotonic Manager
*
- *
- * COPYRIGHT (c) 1989-1999.
+ * COPYRIGHT (c) 1989-2007.
* On-Line Applications Research Corporation (OAR).
*
* The license and distribution terms for this file may be
@@ -68,6 +67,8 @@ rtems_status_code rtems_rate_monotonic_create(
_Watchdog_Initialize( &the_period->Timer, NULL, 0, NULL );
+ _Rate_monotonic_Reset_statistics( the_period );
+
_Objects_Open(
&_Rate_monotonic_Information,
&the_period->Object,
@@ -1,8 +1,7 @@
/*
- * Rate Monotonic Manager
+ * Rate Monotonic Manager -- Create a Period
*